@@ -42,7 +42,8 @@ set_in_env <- function(...) {
 #'   be saved. Overrides `temp`.
 #' @param echo_cmd Passed into [processx::process$new()][processx::process].
 #' @param extra_args A character vector of extra arguments to pass into the
-#'   Selenium Server call.
+#'   Selenium Server call. See the list of options here:
+#'   <https://www.selenium.dev/documentation/grid/configuration/cli_options/>
 #'
 #' @returns A [processx::process] object. Call `<process>$kill()` to stop the
 #'   server.
@@ -51,11 +52,24 @@ set_in_env <- function(...) {
 #' The [package website](https://ashbythorpe.github.io/selenium-r/index.html)
 #' for more ways to start the Selenium server.
 #'
-#' @examplesIf rlang::is_interactive()
+#' @examples
+#' \dontrun{
+#' # Disables the prompt that asks you whether you want to download Selenium server
 #' server <- selenium_server(interactive = FALSE)
 #'
+#' # Saves the server in your user data directory
+#' server <- selenium_server(temp = FALSE)
 #' server$kill()
 #'
+#' # The server doesn't have to be downloaded again
+#' server <- selenium_server(temp = FALSE)
+#'
+#' # Here we use extra arguments to increase the timeout of client sessions,
+#' # allowing sessions to stay open for longer without being automatically
+#' # terminated.
+#' server <- selenium_server(extra_args = c("--session-timeout", "3000"))
+#' }
+#'
 #' @export
 selenium_server <- function(version = "latest",
                             selenium_manager = TRUE,
@@ -186,7 +200,7 @@ download_server <- function(path, file, name, verbose) {
   file
 }
 
-get_latest_version_name <- function(page = 1) {
+get_latest_version_name <- function() {
   sel_env <- get_selenium_env()
 
   stored_name <- get_from_env("latest_version_name")
@@ -194,8 +208,8 @@ get_latest_version_name <- function(page = 1) {
     return(stored_name)
   }
 
-  req <- httr2::request("https://api.github.com/repos/seleniumHQ/selenium/tags")
-  req <- httr2::req_headers(req, "Accept" = "application/vnd.github.v3+json")
+  req <- httr2::request("https://api.github.com/repos/seleniumHQ/selenium/releases/latest")
+  req <- httr2::req_headers(req, "Accept" = "application/vnd.github+json")
 
   token <- if (is_installed("gitcreds")) {
     tryCatch(
@@ -211,19 +225,12 @@ get_latest_version_name <- function(page = 1) {
     req <- httr2::req_headers(req, Authorization = token)
   }
 
-  req <- httr2::req_url_query(req, per_page = 100, page = page)
   response <- httr2::req_perform(req)
-  releases <- httr2::resp_body_json(response)
-
-  latest_tag <- find_using(releases, is_nonspecific_release)
-
-  if (is.null(latest_tag)) {
-    get_latest_version_name(page = page + 1)
-  }
-
-  set_in_env(latest_version_name = latest_tag$name)
-
-  latest_tag$name
+  release <- httr2::resp_body_json(response)
+  
+  url_parts <- strsplit(release$html_url, split = "/")[[1]]
+  
+  url_parts[[length(url_parts)]]
 }
 
 get_version_from_files <- function(error) {
